﻿using CMS;
using CMS.CustomTables;
using CMS.EventLog;
using CMS.Scheduler;
using System;
using System.Net;


[assembly: RegisterCustomClass("Custom.ContentReplacementValidationTask", typeof(Custom.ContentReplacementValidationTask))]
namespace Custom
{
    public class ContentReplacementValidationTask : ITask
    {
        /// <summary>
        /// Executes the task.
        /// </summary>
        /// <param name="ti">Info object representing the scheduled task</param>
        public string Execute(TaskInfo ti)
        {
            try
            {
                int intTotalValidRecords = 0;
                int intTotalInvalidRecords = 0;

                // Get the content replacement links that have not been validated in the last 7 days
                var items = CustomTableItemProvider.GetItems("Custom.ContentURLReplacementTable")
                    .WhereGreaterThan("lastValidated", DateTime.Now.AddDays(-7));

                foreach (var item in items)
                {
                    // Validate the replacement url
                    HttpWebRequest request = WebRequest.Create(item.GetStringValue("ReplacementURL", "")) as HttpWebRequest;
                    request.AllowAutoRedirect = false;
                    using (HttpWebResponse response = request.GetResponse() as HttpWebResponse)
                    {
                        if (response.StatusCode == HttpStatusCode.OK)
                        {
                            // Set the record as valid and add the timestamp
                            item.SetValue("Validated", true);
                            item.SetValue("LastValidated", DateTime.Now);
                            item.Update();
                            intTotalValidRecords += 1;
                        }
                        else
                        {
                            // Update the custom table record
                            item.SetValue("Validated", false);
                            item.Update();
                            intTotalInvalidRecords += 1;
                        }
                    };                    
                }

                return "Total valid records: " + intTotalValidRecords + " Total invalid records: " + intTotalInvalidRecords;
            }
            catch (Exception ex)
            {
                EventLogProvider.LogException("ContentReplacementVerificationTask", "EXECUTE", ex);
                return ex.Message;
            }
        }
    }
}